@@ -1,5 +1,9 @@
 from .in_memory import InMemoryRateLimitingRepo
-from .postgres import PostgresRateLimitingRepo
+
+try:
+    from .postgres import PostgresRateLimitingRepo
+except ImportError:
+    PostgresRateLimitingRepo = None  # type: ignore
 from .sqlite import SqliteRateLimitingRepo
 
 __all__ = [
